import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
import requests


def get_real_auth_ip():
    response = requests.get('http://10.3.38.7')
    redirected_url = response.url
    # http://10.3.191.8 => 10.3.191.8
    redirected_ip = redirected_url.split('/')[2]
    return redirected_ip


def main():
    print(get_real_auth_ip())
    pass


if __name__ == '__main__':
    main()



import getpass
import os


def get_sys_login_user():
    return getpass.getuser()


def get_sys_login_user_home_path():
    login_user_home_path = os.path.join('/home', get_sys_login_user())
    return login_user_home_path


def get_config_file_path():
    # config_file_path = os.path.join(get_sys_login_user_home_path(), '.cau_auth_config')
    config_file_path = os.path.join(os.path.expanduser('~'), '.cau_auth_config')
    return config_file_path


if __name__ == '__main__':
    print(get_sys_login_user_home_path())



import json
import os
import sys
import time

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
import requests
from src.core import real_auth_ip
from src.core import check_status
from src.utils import get_host_ip


def logout():
    """
    :return: dr1002({"result":1,"wopt":0,"msg":14,"uid":"","hidm":0,"hidn":-5,"ss5":"10.2.246.167","ss6":"10.3.38.7","vid":0,"ss1":"000d48448ce8","ss4":"000000000000","cvid":0,"pvid":0,"hotel":0,"aolno":20122,"eport":-1,"eclass":1,"time":7372,"flow":4936051,"fsele":1,"fee":0,"v6af":0,"v6df":0,"actM":1,"actt":129,"actdf":56,"actuf":0,"act6df":0,"act6uf":0,"allfm":2,"d1":224,"u1":138,"d2":0,"u2":0,"o1":0,"nd1":224,"nu1":138,"nd2":0,"nu2":0,"no1":0})
    """
    auth_ip = real_auth_ip.get_real_auth_ip()
    url = f"http://{auth_ip}/drcom/logout?callback=dr1002&v=7912"

    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36',
        'Accept': '*/*',
        'Referer': 'http://10.3.38.7/',
        'Accept-Language': 'zh-CN,zh;q=0.9',
        'Cookie': 'PHPSESSID=mve8c7kvtso03dqcknjsu22bv1'
    }

    response = requests.request("GET", url, headers=headers)

    return response.text.strip()

    pass


def get_live_device_list(ac):
    """
    :param ac: 用户名
    :return: [{"sessionid":36976,"logintime":"2021-10-09 10:16:00","loginip":"10.6.53.8","loginmac":"3C22FB958456","devicetype":"PC"}]
    """
    # 获取毫秒时间戳
    msec_timestamp = int(time.time() * 1000)

    # 获取在线设备
    url = f"""
        http://10.3.38.7:801/eportal/?c=ServiceInterface&a=loadOnlineDevice&callback=jQuery111307422641681895024_{msec_timestamp}&account={ac}&_={msec_timestamp}
        """
    response = requests.get(url)
    response_text = response.text
    # jQuery111309758939784360352_1633746542401({"result ... }) => {"result ... }
    response_dict = response_text[response_text.find('{'):-1]
    response_dict = json.loads(response_dict)
    data = response_dict['data']
    return data


def _force_logout(ac, session_id):
    # 获取毫秒时间戳
    msec_timestamp = int(time.time() * 1000)

    url = f"""
    http://10.3.38.7:801/eportal/?c=ServiceInterface&a=offlineUserDevice&callback=jQuery111308603583689084444_{msec_timestamp}&account={ac}&sessionid={session_id}&_=1633747340884
    """
    response = requests.get(url)
    response_text = response.text
    response_dict = response_text[response_text.find('{'):-1]
    response_dict = json.loads(response_dict)
    result = response_dict['result']
    if result == 'ok':
        return True
    else:
        return False

    pass


def get_local_session_id(ac):
    # 获取在线设备列表
    live_device_list = get_live_device_list(ac)

    # 获取当前机器的ip
    host_ip = get_host_ip.get_host_ip()

    # 匹配当前机器的session_id
    for live_device in live_device_list:
        login_ip = live_device['loginip']
        if login_ip == host_ip:
            session_id = live_device['sessionid']
            return session_id

    # 啥也没找到
    return None


def force_logout():
    # 先检查是否登录，如果没有登录，就不用执行了
    status_info_dict = check_status.check_status()
    if status_info_dict['login'] == 0:
        print('当前未登录，不需要登出')
        return False

    # 如果登录了，就获取登录名
    ac = status_info_dict['AC']

    # 获取当前设备的session_id
    session_id = get_local_session_id(ac)
    if session_id is None:
        print('ERROR:未在登录设备中找到本机')

    # 登出
    _force_logout(ac, session_id)
    print('登出成功')
    return True

    pass


def main():
    # print(logout())
    force_logout()


if __name__ == '__main__':
    main()



import socket


def get_host_ip():
    """
    查询本机ip地址
    :return:
    """
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    try:
        s.connect(('8.8.8.8', 80))
        ip = s.getsockname()[0]
    finally:
        s.close()

    return ip


def main():
    print(get_host_ip())


if __name__ == '__main__':
    main()



import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
from src.utils import sys_user


def create_config():
    config_file_path = sys_user.get_config_file_path()
    if os.path.exists(config_file_path):
        raise FileExistsError('配置文件已经存在')

    # 复制配置文件
    with open(os.path.join(root_path, 'statics/config_example.txt'), 'r', encoding='utf8') as reader:
        config_example = reader.read()
        username = input('请输入你的用户名：')
        password = input('请输入你的密码：')
        config_example = config_example.replace('这里填你的用户名', username)
        config_example = config_example.replace('这里填你的密码', password)
        with open(config_file_path, 'w', encoding='utf8') as writer:
            writer.write(config_example)



import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
from src.utils import args_parser
from src.utils import sys_user


def read_info_from_config():
    config_file_path = sys_user.get_config_file_path()
    if not os.path.exists(config_file_path):
        print(f'配置文件路径不存在:{config_file_path},请手动指定用户名和密码，例如：cau -i -u 用户名 -p 密码')
        return None, None
    # print(f'config_file_path:{config_file_path}')
    # config_file_path = os.path.join(root_path, 'statics/config_test.txt')
    config_file_reader = open(config_file_path, 'r', encoding='utf8')
    config_info_dict = {}
    for config_line in config_file_reader:
        config_line = config_line.strip()
        # 是不是空行
        if len(config_line) == 0:
            continue

        # 是不是以#号开头
        if config_line[0:1] == '#':
            continue

        # 找有没有等号=
        equal_symbol_index = config_line.find('=')
        if equal_symbol_index == -1:
            continue

        # 如果在一行中有等号出现
        key = config_line[0:equal_symbol_index].strip()
        value = config_line[equal_symbol_index + 1:].strip()
        config_info_dict[key] = value

    config_file_reader.close()
    username = config_info_dict.get('username')
    password = config_info_dict.get('password')

    return username, password

    pass


def get_init_args():
    """
    获取初始化参数
    系统会先尝试读取启动参数
    如果启动参数不够或不全，则会读取当前登录用户根目录下的配置文件，例如/home/ning/.cau_auth_config
    :return:
    """
    args = args_parser.get_parse_res()

    if args.logout:
        action = 'logout'
    elif args.check_status:
        action = 'check_status'
    elif args.create_config:
        action = 'create_config'
    elif args.login:
        action = 'login'
    else:
        action = 'none'

    username = args.username
    password = args.password

    # 当当前的行为是login，并且用户名和密码有一个未被指定时
    if action == 'login' and (
            (username is None and password is not None) or (username is not None and password is None)):
        raise ValueError('username和password必须同时指定或者都不指定(这时会读取用户根目录下的.cau_auth_config文件)')

    # 当当前的行为是login，并且用户名和密码未被全部指定时，
    if action == 'login' and username is None and password is None:
        # 读取配置文件
        username, password = read_info_from_config()
        # 判断是否顺利读取到了username和password
        if username is None or password is None:
            raise ValueError('读取配置文件出错')

    init_args = {
        'action': action,
        'username': username,
        'password': password
    }

    return init_args


def test_read_info_from_config():
    print(read_info_from_config())


if __name__ == '__main__':
    test_read_info_from_config()



import json
import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
import requests
from src.core import real_auth_ip


def _check_status():
    """
    :return: 未登录：{"result":0,"m46":0,"v46ip":"10.2.246.167","myv6ip":"","sv":0,"domain":"[::]","v6":"http://[::]:9002/v6","ss5":"10.2.246.167","ss6":"10.3.38.7","vid":0,"ss1":"000d48448ce8","ss4":"000000000000","cvid":0,"pvid":0,"hotel":0,"aolno":20056,"eport":-1,"eclass":1,"zxopt":1,"AC":"","wopt":0,"v4serip":"10.3.38.7","hidm":0,"hidn":-5}
        已登录：{"result":1,"time":7376,"flow":4946277,"fsele":1,"fee":0,"m46":0,"v46ip":"10.2.246.167","myv6ip":"","oltime":4294967295,"olflow":16034816,"lip":"10.2.246.167","stime":"2021-09-11 13:40:37","etime":"2021-09-11 13:41:30","uid":"用户名","v6af":0,"v6df":0,"v46m":0,"v4ip":"10.2.246.167","v6ip":"::","AC":"用户名","ss5":"10.2.246.167","ss6":"10.3.38.7","vid":0,"ss1":"000d48448ce8","ss4":"000000000000","cvid":0,"pvid":0,"hotel":0,"aolno":19756,"eport":-1,"eclass":1,"zxopt":1,"NID":"宁远霖","olno":0,"udate":"","olmac":"000000000000","ollm":0,"olm1":"00000000","olm2":"0000","olm3":0,"olmm":1,"olm5":0,"gid":24,"actM":1,"actt":192,"actdf":10056,"actuf":0,"act6df":0,"act6uf":0,"allfm":1,"d1":0,"u1":0,"d2":0,"u2":0,"o1":0,"nd1":40224,"nu1":3116,"nd2":0,"nu2":0,"no1":0}
    """
    auth_ip = real_auth_ip.get_real_auth_ip()
    url = f"http://{auth_ip}/drcom/chkstatus?callback=dr1002&v=10311"

    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36',
        'Accept': '*/*',
        'Referer': 'http://10.3.38.7/',
        'Accept-Language': 'zh-CN,zh;q=0.9',
        'Cookie': 'PHPSESSID=mve8c7kvtso03dqcknjsu22bv1'
    }

    response = requests.request("GET", url, headers=headers)

    response_text = response.text.strip()
    start_index = response_text.find('(') + 1
    response_json_text = response_text[start_index:-1]

    response_json_dict = json.loads(response_json_text)

    return response_json_dict


def check_status():
    """

    :return: is login:{'login':1,'username':'...'} else {'login':0,'username':''}
    """
    status_info_dict = _check_status()
    result = status_info_dict['result']
    if result == 1:
        username = status_info_dict['NID']
        ac = status_info_dict['AC']  # 用户名
    else:  # result == 0
        username = ''
        ac = ''

    res = {
        'login': result,
        'username': username,
        'AC': ac
    }

    return res


def main():
    print(check_status())


if __name__ == '__main__':
    main()



import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)
import requests
import json
from src.core import real_auth_ip
from src.core import check_status


def _login(username, password, auth_ip):
    base_url = "http://{auth_ip}/drcom/login?callback=dr1003&DDDDD={username}&upass={password}&0MKKey=123456&R1=0&R3=0&R6=0&para=00&v6ip=&v=6817"
    url = base_url.format(auth_ip=auth_ip, username=username, password=password)

    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36',
        'Accept': '*/*',
        'Referer': 'http://10.3.38.7/a79.htm?isReback=1',
        'Accept-Language': 'zh-CN,zh;q=0.9',
        'Cookie': 'PHPSESSID=mve8c7kvtso03dqcknjsu22bv1'
    }

    response = requests.request("GET", url, headers=headers)

    response_text = response.text.strip()
    response_dict = response_text[response_text.find('{'):-1]
    response_dict = json.loads(response_dict)
    is_success = response_dict['result']
    if is_success == 0:
        msg = response_dict['msga']
    else:
        msg = ''
    return is_success, msg


def login(username, password):
    """

    :param username:
    :param password:
    :return: dr1003({"result":1,"aolno":20554,"m46":0,"v46ip":"10.2.246.167","myv6ip":"","sms":0,"ufee":0,"NID":"宁远霖","olno":1,"udate":"","olmac":"000000000000","ollm":0,"olm1":"00000000","olm2":"0000","olm3":0,"olmm":2,"olm5":0,"gid":24,"olno":1,"olip":"10.6.56.59","oaf":101847,"oat":17707,"mac1":"","mac2":"","mac3":"","mac4":"","mac5":"","mac6":"","ac0":"czIwMjEzMDgxNTIw","oltime":4294967295,"olflow":16147456,"lip":"10.2.246.167","stime":"2021-09-11 13:08:50","etime":"2021-09-11 13:11:38","uid":"用户名","UL":"http://wdl1.cache.wps.cn/per-plugin/dl/addons/list/win-i386/3.7.0.5929/wpsoffice/index.ini","sv":0})
    """
    # 先验证账号是否登录，如果已经登录了，还进行登录操作，回导致接口阻塞无法获取返回值，并且原登录态会退出
    status_info_dict = check_status.check_status()
    is_login = status_info_dict['login']
    if is_login == 1:
        login_username = status_info_dict['username']
        msg = f'账号已经登陆，当前登陆的用户为:{login_username}'
        return 0, msg

    auth_ip = real_auth_ip.get_real_auth_ip()

    # print(auth_ip)

    is_success, msg = _login(username, password, auth_ip)

    if is_success == 0:
        # 在部分网关下，需要在username后加上 @ cau才能正确登录
        is_success, msg = _login(username + '@cau', password, auth_ip)

    return is_success, msg

    pass


def main():
    username = '用户名'
    password = '密码'
    print(login(username, password))


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages

setup(
    name='cau',
    version='0.0.1',  # 版本号
    description='通过命令行进行中国农业大学的校园网认证',
    author='nyl',
    author_email='c2605759123@163.com',
    url='https://github.com/NingYuanLin/cau_auth',
    # py_modules=['cau'],
    entry_points={
        'console_scripts': ['cau=cau_auth.cau:main']
    },
    # packages=['src.core', 'src.helper', 'src.utils', 'statics'],
    # package_data={
    #     "cau_auth": ["statics/*"]
    # },
    packages=find_packages(),
    # package_dir={'': 'cau_auth'},
    include_package_data=True,
)



import os
import sys

root_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
sys.path.append(root_path)

import argparse


def get_parse_res():
    with open(os.path.join(root_path, 'statics/argparse_description.txt'), encoding='utf8') as reader:
        parser = argparse.ArgumentParser(description=reader.read())

    parser.add_argument('-i', '--login', action="store_true", help='登录校园网')
    parser.add_argument('-o', '--logout', action="store_true", help='注销校园网')
    parser.add_argument('-s', '--check_status', action="store_true", help='检查登录状态')
    parser.add_argument('-c', '--create_config', action="store_true", help='在用户根目录下创建配置文件')

    parser.add_argument('-u', '--username', help="cau校园网的用户名", type=str)
    parser.add_argument('-p', '--password', help='cau校园网的密码', type=str)

    args = parser.parse_args()

    return args


def test():
    print(get_parse_res())
    pass


if __name__ == '__main__':
    test()



import os
import sys

root_path = os.path.dirname(os.path.realpath(__file__))
sys.path.append(root_path)
from src.helper import init_helper
from src.core import login
from src.core import logout
from src.core import check_status
from src.core import create_config


def main():
    try:
        init_args = init_helper.get_init_args()
    except ValueError as e:
        print(str(e))
        exit(1)
    else:
        action = init_args['action']
        username = init_args['username']
        password = init_args['password']
        if action == 'login':
            print('正在登录账户')
            is_success, msg = login.login(username, password)
            if is_success == 1:
                print('登录账户成功')
            else:
                print(f'登录账户失败，错误信息:{msg}')
        elif action == 'logout':
            print('正在注销账户')
            logout.force_logout()
            print('账户注销结束')
        elif action == 'check_status':
            status_info_dict = check_status.check_status()
            is_login = status_info_dict['login']
            if is_login == 1:
                login_username = status_info_dict['username']
                print(f'账号已经登陆，当前登陆的用户为:{login_username}')
            else:
                print('当前未登录')
        elif action == 'create_config':
            try:
                create_config.create_config()
            except FileExistsError as e:
                print(e)
                exit(1)
            else:
                print(f'配置文件生成成功')
        else:
            print('参数不合法：请指定行为（-i：登录；-o：注销；-s：检查登录状态；-c：在用户根目录下创建配置文件）')
            exit(1)

    pass


if __name__ == '__main__':
    main()
